@@ -50,8 +50,49 @@ SLUGIFY_SOURCE = 'basename'
 
 ARTICLE_URL = 'articles/{date:%Y}/{date:%b}/{date:%d}/{slug}/'
 ARTICLE_SAVE_AS = 'articles/{date:%Y}/{date:%b}/{date:%d}/{slug}/index.html'
-PAGE_URL = 'pages/{slug}/'
+PAGE_URL = 'pages/{slug}/index.html'
 PAGE_SAVE_AS = 'pages/{slug}/index.html'
 
 # Uncomment following line if you want document-relative URLs when developing
 RELATIVE_URLS = True
+
+
+PLUGINS = ['i18n_subsites',]
+
+STATIC_TRANSLATIONS = {
+    "Summary": "Sommaire",
+    "Translations": "Traductions",
+}
+
+HIDE_LANG = 'fr'
+
+I18N_SUBSITES = {
+    'en-us': {
+        'SITENAME': 'SLM-Help',
+        'SITETITLE': '..:: SLM : Help ::..',
+        'HIDE_LANG': 'fr',
+        'STATIC_TRANSLATIONS': {
+            "Summary": "Summary",
+            "Translations": "Translations",
+        },
+    },
+    'es-es': {
+        'SITENAME': 'SLM-Ayuda',
+        'SITETITLE': '..:: SLM : Ayuda ::..',
+        'HIDE_LANG': 'fr',
+        'STATIC_TRANSLATIONS': {
+            "Summary": "Sumario",
+            "Translations": "Traducciones",
+        },
+    },
+    'fr-fr': {
+        'SITENAME': 'SLM-Aide',
+        'SITETITLE': '..:: SLM : Aide ::..',
+        'HIDE_LANG': 'fr',
+        'STATIC_TRANSLATIONS': {
+            "Summary": "Sommaire",
+            "Translations": "Traductions",
+        },
+    },
+}
+
