@@ -24,7 +24,7 @@ from .models import Classes, Parametres, Disciplines, Niveaux, Filieres, \
     Series, TypeMateriel, Courriers, Commandes, Personnels, \
     Eleves, Eleves_de_siecle, Materiel, Inventaire, Details, Prets, Caution, \
     RevueStock, Jeton, LivreSupplement, Livre_a_lire, Rachat, Digraphe_select, \
-    Digraphe
+    Digraphe, CompteMateriel
 
 admin.site.register(Classes)
 admin.site.register(Parametres)
@@ -97,3 +97,7 @@ admin.site.register(Eleves, ElevesAdmin)
 class MaterielAdmin(admin.ModelAdmin):
     list_filter = ["discipline", "niveau"]
 admin.site.register(Materiel, MaterielAdmin)
+
+class CompteMaterielAdmin(admin.ModelAdmin):
+    list_filter = ["materiel__titre"]
+admin.site.register(CompteMateriel, CompteMaterielAdmin)
