@@ -6,6 +6,9 @@ def assure_jeton_valide(view_func):
     def wrapped_view(*arg, **kwargs):
         request = arg[0]
         jeton_id = request.session.get("jeton")
+        if jeton_id is None:
+            jeton_id = request.GET.get("jeton")
+            request.session["jeton"] = jeton_id
         jetons = Jeton.objects.filter(id = jeton_id)
         if jetons and jetons[0].estValide():
             result = view_func(*arg, **kwargs)
