@@ -939,11 +939,18 @@ ADRESSE : .....................................................................
         s = self.string("Location : 55 €", fontSize=12) 
         self.adjustXY(s, x, y)
         self.pylabel.add(s)
-        s = self.string(
-            "Esp. ☐ ; Chq. ☐ ; HDF N°........................",
-            fontSize=12)
+        s = self.string("Esp. ☐ ; Chq. ☐ \\", fontSize=12)
         self.adjustXY(s, x + 36, y)
         self.pylabel.add(s)
+        s = self.string("{", fontSize=32)
+        self.adjustXY(s, x + 68, y -4)
+        self.pylabel.add(s)
+        s = self.string("HDF N° . . . . . . .", fontSize=12)
+        self.adjustXY(s, x + 73, y)
+        self.pylabel.add(s)
+        s = self.string("Fameco ? ☐", fontSize=12)
+        self.adjustXY(s, x + 73, y-5)
+        self.pylabel.add(s)        
         s = self.string("Masse : 12 €", fontSize=12)
         self.adjustXY(s, x, y-6)
         self.pylabel.add(s)
