@@ -116,18 +116,26 @@ class TestAvecBDD(StaticLiveServerTestCase):
         # choix du français
         self.selenium.find_element(
             By.CSS_SELECTOR, "#language-fr img").click()
-        #un peu d'attente
+        # un peu d'attente
         ActionChains(self.selenium).pause(.5).perform()
         img = self.selenium.find_element(By.CSS_SELECTOR, '#aide img')
         self.assertEqual(img.get_attribute("title"), "Aide contextuelle")
         # choix de l'espagnol
         img_es = self.selenium.find_element(
             By.CSS_SELECTOR, "#language-es img").click()
-        #un peu d'attente
+        # un peu d'attente
         ActionChains(self.selenium).pause(.5).perform()
         img = self.selenium.find_element(By.CSS_SELECTOR, '#aide img')
         self.assertEqual(img.get_attribute("title"), "Ayuda contextual")
 
+        # retour au français
+        self.selenium.find_element(
+            By.CSS_SELECTOR, "#language-fr img").click()
+        # un peu d'attente
+        ActionChains(self.selenium).pause(.5).perform()
+        img = self.selenium.find_element(By.CSS_SELECTOR, '#aide img')
+        self.assertEqual(img.get_attribute("title"), "Aide contextuelle")
+
         """
         Login en tant que 'testuser'
         """
