@@ -278,4 +278,9 @@ urlpatterns = [
     path('messages_eleves', views_download.messages_eleves, name='messages_eleves'),
     path('recompte_pour_maintenant', ajaxviews.recompte_pour_maintenant, name='recompte_pour_maintenant'),
     re_path(r"^pour_qui_ce_livre/(?P<ident>.*)", views_download.pqcl),
+    path('eleves_de_classe', ajaxviews.eleves_de_classe, name='eleves_de_classe'),
+    path('amp', ajaxviews.amp, name='amp'),
+    path('app', ajaxviews.app, name='app'),
+    path('etl', ajaxviews.etl, name='etl'),
+    path('mcm', ajaxviews.mcm, name='mcm'),
 ]
