@@ -22,6 +22,7 @@ from django.utils.translation import gettext_lazy as _
 from django.utils.translation import activate, get_language_info
 
 from .version import this_version
+from manuels.settings import language_for
 
 import unicodedata
 
@@ -49,6 +50,7 @@ Les_onglets = [ ## accès aux pages de niveau 1
     Onglet(_("À propos"), "apropos", pour_tous = True),
 ]
 
+
 def render_common(request, template, subtitle="", context=None,
                   content_type=None, status=None, using=None,
                   pour_tous=False):
@@ -75,6 +77,7 @@ def render_common(request, template, subtitle="", context=None,
         "onglets": Les_onglets,
         "page_pour_tous": pour_tous,
         "lalangue": lalangue,
+        "locale": language_for(lalangue),
     }
     if context is None:
         context = dico
@@ -84,8 +87,3 @@ def render_common(request, template, subtitle="", context=None,
         dico["aide"] = True
     return render(request, template, context, content_type, status, using)
     
-def unaccent(s):
-    """
-    désaccentue une chaîne
-    """
-    return unicodedata.normalize('NFD',s).encode('ascii', 'ignore').decode("utf-8")
